@@ -14,25 +14,25 @@ summary.PAFit_result <- function(object,...){
   
     if (object$only_f == FALSE) {
         if (object$auto_lambda == TRUE) {
-            cat("Ratio (r): ", object$ratio,"\n");
-        } else cat("Lambda used: ", object$lambda,"\n");
+            cat("Ratio (r):", object$ratio,"\n");
+        } else cat("Lambda used:", object$lambda,"\n");
     }
     if (object$only_PA == FALSE)
-        cat("Prior of node fitness: shape: ",object$shape,"; rate: ",object$rate,"\n")
-    cat("Estimated attachment exponent: ",object$alpha,"\n");
+        cat("Prior of node fitness: shape: ",object$shape,"; rate: ",object$rate,"\n", sep = "")
+    cat("Estimated attachment exponent:",object$alpha,"\n");
     if (object$ci[1] == "N") {
       cat("No possible confidence interval for the estimated attachment exponent.\n");
     } else if (object$mode_f != "Log_linear") {
-      cat("Two-sigma confidence interval of the attachment exponent: (", object$ci[1], ",", 
-          object$ci[2],")\n");
+      cat("Attachment exponent ","\u00B1", " 2 s.d.", ": (", object$ci[1], ",", 
+          object$ci[2],")\n",sep = "");
     }
     else {
-      cat("Two-sigma confidence interval of the attachment exponent: (", object$ci[1], ",", 
-          object$ci[2],")\n");  
+      cat("Attachment exponent ","\u00B1", " 2 s.d.", ": (", object$ci[1], ",", 
+          object$ci[2],")\n",sep = "");  
     }
     cat("-------------------------------------------\n")
     cat("Additional information: \n");
-    cat("Number of bins: ", object$g,"\n");
-    cat("Number of iterations: ",length(object$objective_value) - 1,"\n");
+    cat("Number of bins:", object$g,"\n");
+    cat("Number of iterations:",length(object$objective_value) - 1,"\n");
     cat("Stopping condition:", object$stop_cond,"\n");
 }
\ No newline at end of file
